aboutsummaryrefslogtreecommitdiff
path: root/cmd/update.go
diff options
context:
space:
mode:
Diffstat (limited to 'cmd/update.go')
-rw-r--r--cmd/update.go5
1 files changed, 3 insertions, 2 deletions
diff --git a/cmd/update.go b/cmd/update.go
index f8b2219..b6f2882 100644
--- a/cmd/update.go
+++ b/cmd/update.go
@@ -26,7 +26,8 @@ var updateCmd = &cobra.Command{
cache, cacheDir := getCache()
defer cache.Close()
- // sync data, get changed data
- nvdmirror.Sync(config, &cache, cacheDir)
+ // sync data, get updates
+ updates := nvdmirror.Sync(config, &cache, cacheDir)
+ jsonEncode(updates)
},
}